@@ -20,6 +20,7 @@ import contextlib
 import http.client
 import json as stdlib_json  # pylint: disable=preferred-module
 import os
+import sys
 from asyncio import set_event_loop_policy
 from collections.abc import Callable
 from configparser import RawConfigParser
@@ -102,7 +103,10 @@ def apply() -> None:
         type for type, data in MEDIA_TYPES.items() if data.get("compressible")
     }
     http.client.responses[420] = "Enhance Your Calm"
-    if not getattr(stdlib_json, "_omegajson", False):
+    if not getattr(stdlib_json, "_omegajson", False) and sys.version_info < (
+        3,
+        12,
+    ):
         patch_json()
     anonymize_logs()
     patch_emoji()
