@@ -21,7 +21,7 @@ import math
 import os
 import sys
 import textwrap
-from collections.abc import Iterable
+from collections.abc import Iterable, Mapping
 from tempfile import TemporaryDirectory
 from typing import Any, ClassVar, Final
 
@@ -61,28 +61,22 @@ HOST_NAME_FONT: Final = ImageFont.truetype(
     size=23,
 )
 
-FILE_EXTENSIONS = {
+FILE_EXTENSIONS: Final[Mapping[str, str]] = {
     "bmp": "bmp",
     "gif": "gif",
     "jfif": "jpeg",
     "jpe": "jpeg",
     "jpeg": "jpeg",
     "jpg": "jpeg",
-    "jxl": "jxl",
+    **({"jxl": "jxl"} if hasattr(patches, "JXLImagePlugin") else {}),
     "pdf": "pdf",
     "png": "png",
     "spi": "spider",
     "tiff": "tiff",
     "webp": "webp",
-    "xlsx": "xlsx",
+    **({"xlsx": "xlsx"} if to_excel else {}),
 }
 
-if not to_excel:
-    del FILE_EXTENSIONS["xlsx"]
-
-if not hasattr(patches, "JXLImagePlugin"):
-    del FILE_EXTENSIONS["jxl"]
-
 
 def load_png(filename: str) -> Image.Image:
     """Load a PNG image into memory."""
@@ -92,10 +86,10 @@ def load_png(filename: str) -> Image.Image:
         return image.copy()
 
 
-BACKGROUND_IMAGE = load_png("bg")
+BACKGROUND_IMAGE: Final = load_png("bg")
 IMAGE_WIDTH, IMAGE_HEIGHT = BACKGROUND_IMAGE.size
-WITZIG_IMAGE = load_png("StempelWitzig")
-NICHT_WITZIG_IMAGE = load_png("StempelNichtWitzig")
+WITZIG_IMAGE: Final = load_png("StempelWitzig")
+NICHT_WITZIG_IMAGE: Final = load_png("StempelNichtWitzig")
 
 
 def get_lines_and_max_height(
@@ -320,7 +314,7 @@ def create_image(  # noqa: C901  # pylint: disable=too-complex
 class QuoteAsImage(QuoteReadyCheckHandler):
     """Quote as image request handler."""
 
-    POSSIBLE_CONTENT_TYPES: ClassVar[list[str]] = [  # type: ignore[assignment]
+    POSSIBLE_CONTENT_TYPES: ClassVar[tuple[str, ...]] = (
         "text/html",
         *{
             f"image/{type}"
@@ -328,7 +322,7 @@ class QuoteAsImage(QuoteReadyCheckHandler):
             if type not in {"pdf", "xlsx"}
         },
         "application/pdf",
-    ]
+    ) + (("application/vnd.ms-excel",) if to_excel else ())
     RATELIMIT_GET_LIMIT: ClassVar[int] = 15
     IS_NOT_HTML: ClassVar[bool] = True
 
@@ -404,7 +398,3 @@ class QuoteAsImage(QuoteReadyCheckHandler):
                 wq_id=wrong_quote.get_id_as_str(),
             )
         )
-
-
-if to_excel:
-    QuoteAsImage.POSSIBLE_CONTENT_TYPES.append("application/vnd.ms-excel")
