@@ -166,7 +166,12 @@ class QuoteBaseHandler(QuoteReadyCheckHandler):
 
         This is done to show the users less out-of-date data.
         """
-        if len(self.FUTURES) > 1 or (self.content_type or "")[:6] == "image/":
+        if len(self.FUTURES) > 1 or (
+            self.content_type
+            and self.content_type.startswith("image/")
+            or self.content_type
+            in {"application/pdf", "application/vnd.ms-excel"}
+        ):
             return  # don't spam and don't do this for images
 
         user_agent = self.request.headers.get("User-Agent")
@@ -247,6 +252,29 @@ class QuoteRedirectAPI(APIRequestHandler, QuoteBaseHandler):
         )
 
 
+def wrong_quote_to_json(
+    wq_: WrongQuote, vote: int, next_: tuple[int, int], rating: str, full: bool
+) -> dict[str, Any]:  # TODO: improve lazy return type typing
+    """Convert a wrong quote to a dict."""
+    next_q, next_a = next_
+    if full:
+        return {
+            "wrong_quote": wq_.to_json(),
+            "next": f"{next_q}-{next_a}",
+            "vote": vote,
+        }
+    return {
+        "id": wq_.get_id_as_str(),
+        "quote": str(wq_.quote),
+        "author": str(wq_.author),
+        "real_author": str(wq_.quote.author),
+        "real_author_id": wq_.quote.author.id,
+        "rating": rating,
+        "vote": vote,
+        "next": f"{next_q}-{next_a}",
+    }
+
+
 class QuoteById(QuoteBaseHandler):
     """The page with a specified quote that then gets rendered."""
 
@@ -256,6 +284,7 @@ class QuoteById(QuoteBaseHandler):
 
     POSSIBLE_CONTENT_TYPES: ClassVar[tuple[str, ...]] = (
         *HTMLRequestHandler.POSSIBLE_CONTENT_TYPES,
+        *APIRequestHandler.POSSIBLE_CONTENT_TYPES,
         *QuoteAsImage.POSSIBLE_CONTENT_TYPES,
     )
 
@@ -275,19 +304,33 @@ class QuoteById(QuoteBaseHandler):
                     self.LONG_PATH % (wqs[0].quote.id, wqs[0].author.id)
                 )
             )
-        if self.content_type and self.content_type.startswith("image/"):
-            _wq = await get_wrong_quote(int_quote_id, int(author_id))
-            return await self.finish(
-                create_image(
-                    _wq.quote.quote,
-                    _wq.author.name,
-                    _wq.rating,
-                    f"{self.request.host_name}/z/{_wq.get_id_as_str(True)}",
-                    self.content_type.removeprefix("image/"),
-                )
-            )
+
         if head:
             return
+
+        if (
+            self.content_type
+            and self.content_type.startswith("image/")
+            or self.content_type
+            in {"application/pdf", "application/vnd.ms-excel"}
+        ):
+            wrong_quote = await get_wrong_quote(int_quote_id, int(author_id))
+            return await self.finish(
+                create_image(
+                    wrong_quote.quote.quote,
+                    wrong_quote.author.name,
+                    wrong_quote.rating,
+                    f"{self.request.host_name}/z/{wrong_quote.get_id_as_str(True)}",
+                    self.content_type.removeprefix("image/")
+                    if self.content_type.startswith("image/")
+                    else {
+                        "application/pdf": "pdf",
+                        "application/vnd.ms-excel": "xlsx",
+                    }[self.content_type],
+                    wq_id=wrong_quote.get_id_as_str(),
+                )
+            )
+
         await self.render_quote(int_quote_id, int(author_id))
 
     async def get_old_vote(
@@ -396,6 +439,16 @@ class QuoteById(QuoteBaseHandler):
         self, wrong_quote: WrongQuote, vote: int
     ) -> None:
         """Render the page with the wrong_quote and this vote."""
+        if self.content_type in APIRequestHandler.POSSIBLE_CONTENT_TYPES:
+            return await self.finish(
+                wrong_quote_to_json(
+                    wrong_quote,
+                    vote,
+                    self.next_id,
+                    await self.get_rating_str(wrong_quote),
+                    self.get_bool_argument("full", False),
+                )
+            )
         await self.render(
             "pages/quotes/quotes.html",
             wrong_quote=wrong_quote,
@@ -441,20 +494,12 @@ class QuoteAPIHandler(APIRequestHandler, QuoteById):
         self, wrong_quote: WrongQuote, vote: int
     ) -> None:
         """Return the relevant data for the quotes page as JSON."""
-        next_q, next_a = self.next_id
-        if self.request.path.endswith("/full"):
-            return await self.finish_dict(
-                wrong_quote=wrong_quote.to_json(),
-                next=f"{next_q}-{next_a}",
-                vote=vote,
+        return await self.finish(
+            wrong_quote_to_json(
+                wrong_quote,
+                vote,
+                self.next_id,
+                await self.get_rating_str(wrong_quote),
+                self.request.path.endswith("/full"),
             )
-        return await self.finish_dict(
-            id=wrong_quote.get_id_as_str(),
-            quote=str(wrong_quote.quote),
-            author=str(wrong_quote.author),
-            real_author=str(wrong_quote.quote.author),
-            real_author_id=wrong_quote.quote.author.id,
-            rating=await self.get_rating_str(wrong_quote),
-            vote=vote,
-            next=f"{next_q}-{next_a}",
         )
