@@ -16,18 +16,36 @@ from __future__ import annotations
 
 import asyncio
 import logging
-from typing import Final
+from typing import Final, Literal, TypeAlias, cast
 
 import orjson as json
 from elastic_enterprise_search import AppSearch  # type: ignore[import]
+from typed_stream import Stream
 
 from .. import NAME
+from ..quotes.utils import (
+    Author,
+    Quote,
+    WrongQuote,
+    get_authors,
+    get_quotes,
+    get_wrong_quotes,
+)
+from ..soundboard.data import ALL_SOUNDS, SoundInfo
+from ..utils import search
 from ..utils.decorators import get_setting_or_default, requires_settings
 from ..utils.request_handler import APIRequestHandler, HTMLRequestHandler
-from ..utils.utils import AwaitableValue, ModuleInfo
+from ..utils.utils import AwaitableValue, ModuleInfo, PageInfo
 
 LOGGER: Final = logging.getLogger(__name__)
 
+UnscoredPageInfo: TypeAlias = tuple[
+    tuple[Literal["url"], str],
+    tuple[Literal["title"], str],
+    tuple[Literal["description"], str],
+]
+OldSearchPageInfo: TypeAlias = search.ScoredValue[UnscoredPageInfo]
+
 
 def get_module_info() -> ModuleInfo:
     """Create and return the ModuleInfo for this module."""
@@ -47,6 +65,16 @@ def get_module_info() -> ModuleInfo:
 class Search(HTMLRequestHandler):
     """The request handler for the search page."""
 
+    def convert_page_info_to_simple_tuple(
+        self, page_info: PageInfo
+    ) -> UnscoredPageInfo:
+        """Convert PageInfo to tuple of tuples."""
+        return (
+            ("url", self.fix_url(page_info.path)),
+            ("title", page_info.name),
+            ("description", page_info.description),
+        )
+
     async def get(self, *, head: bool = False) -> None:
         """Handle GET requests to the search page."""
         if head:
@@ -57,6 +85,15 @@ class Search(HTMLRequestHandler):
             results=await self.search(),
         )
 
+    def get_all_page_info(self) -> Stream[PageInfo]:
+        """Return all page infos that can be found."""
+        return (
+            Stream(self.get_module_infos())
+            .flat_map(lambda mi: mi.sub_pages + (mi,))
+            .exclude(lambda pi: pi.hidden)
+            .filter(lambda pi: pi.path)
+        )
+
     def get_query(self) -> str:
         """Return the query."""
         return str(self.get_argument("q", ""))
@@ -73,11 +110,11 @@ class Search(HTMLRequestHandler):
                     self.apm_client.capture_exception()
         if result is not None:
             return result
-        return await self.search_old(query)
+        return self.search_old(query)
 
     @requires_settings("APP_SEARCH", return_=AwaitableValue(None))
     @get_setting_or_default("APP_SEARCH_ENGINE", NAME.removesuffix("-dev"))
-    async def search_new(
+    async def search_new(  # type: ignore[no-any-unimported]
         self,
         query: str,
         *,
@@ -127,42 +164,95 @@ class Search(HTMLRequestHandler):
             )["results"]
         ]
 
-    async def search_old(self, query: str) -> list[dict[str, str | float]]:
+    def search_old(
+        self, query: str, limit: int = 20
+    ) -> list[dict[str, str | float]]:
         """Search the website using the old search engine."""
-        page_infos: list[tuple[float, list[tuple[str, float | str]]]] = []
-
-        for module_info in self.get_module_infos():
-            score = module_info.search(query)
-            if score > 0:
-                page_infos.append(
-                    (
-                        score,
-                        [
-                            ("url", self.fix_url(module_info.path)),
-                            ("title", module_info.name),
-                            ("description", module_info.description),
-                            ("score", score),
-                        ],
-                    )
-                )
-            for sub_page in module_info.sub_pages:
-                score = sub_page.search(query)
-                if score > 0:
-                    page_infos.append(
-                        (
-                            score,
-                            [
-                                ("url", self.fix_url(sub_page.path)),
-                                ("title", sub_page.name),
-                                ("description", sub_page.description),
-                                ("score", score),
-                            ],
-                        )
-                    )
+        page_infos = self.search_old_internal(query)
 
         page_infos.sort(reverse=True)
 
-        return [dict(info) for _, info in page_infos]
+        return [
+            dict(scored_value.value + (("score", scored_value.score),))
+            for scored_value in page_infos[:limit]
+        ]
+
+    def search_old_internal(self, query: str) -> list[OldSearchPageInfo]:
+        """Search authors and quotes."""
+        if not (query_object := search.Query(query)):
+            return list(
+                self.get_all_page_info()
+                .map(self.convert_page_info_to_simple_tuple)
+                .map(lambda unscored: search.ScoredValue(1, unscored))
+            )
+        pages: search.DataProvider[
+            PageInfo, UnscoredPageInfo
+        ] = search.DataProvider(
+            self.get_all_page_info,
+            lambda page_info: (
+                page_info.name,
+                page_info.description,
+                *page_info.keywords,
+            ),
+            self.convert_page_info_to_simple_tuple,
+        )
+        soundboard: search.DataProvider[
+            SoundInfo, UnscoredPageInfo
+        ] = search.DataProvider(
+            ALL_SOUNDS,
+            lambda sound_info: (sound_info.get_text(), sound_info.person.value),
+            lambda sound_info: (
+                (
+                    "url",
+                    self.fix_url(
+                        f"/soundboard/{sound_info.person.name}#{sound_info.get_filename()}"
+                    ),
+                ),
+                ("title", f"Soundboard ({sound_info.person.value})"),
+                ("description", sound_info.get_text()),
+            ),
+        )
+        authors: search.DataProvider[
+            Author, UnscoredPageInfo
+        ] = search.DataProvider(
+            get_authors,
+            lambda author: author.name,
+            lambda author: (
+                ("url", self.fix_url(author.get_path())),
+                ("title", "Autoren-Info"),
+                ("description", author.name),
+            ),
+        )
+        quotes: search.DataProvider[
+            Quote, UnscoredPageInfo
+        ] = search.DataProvider(
+            get_quotes,
+            lambda quote: (quote.quote, quote.author.name),
+            lambda q: (
+                ("url", self.fix_url(q.get_path())),
+                ("title", "Zitat-Info"),
+                ("description", str(q)),
+            ),
+        )
+        wrong_quotes: search.DataProvider[
+            WrongQuote, UnscoredPageInfo
+        ] = search.DataProvider(
+            lambda: get_wrong_quotes(lambda wq: wq.rating > 0),
+            lambda wq: (wq.quote.quote, wq.author.name),
+            lambda wq: (
+                ("url", self.fix_url(wq.get_path())),
+                ("title", "Falsches Zitat"),
+                ("description", str(wq)),
+            ),
+        )
+        return search.search(
+            query_object,
+            cast(search.DataProvider[object, UnscoredPageInfo], pages),
+            cast(search.DataProvider[object, UnscoredPageInfo], soundboard),
+            cast(search.DataProvider[object, UnscoredPageInfo], authors),
+            cast(search.DataProvider[object, UnscoredPageInfo], quotes),
+            cast(search.DataProvider[object, UnscoredPageInfo], wrong_quotes),
+        )
 
 
 class SearchAPIHandler(APIRequestHandler, Search):
